
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : init-qcl.scm
;; DESCRIPTION : Initialize qcl plugin
;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (qcl-initialize)
  (import-from (utils plugins plugin-convert))
  (lazy-input-converter (qcl-input) qcl))

(plugin-configure qcl
  (:require (url-exists-in-path? "qcl"))
  (:initialize (qcl-initialize))
  (:launch "qcl --texmacs")
  (:session "Qcl"))
